# libpythonpro
Módulo para exemplificar a construção de projetos Python no curso Pytools

Nesse curso é ensinado como contribuir com projetos de código aberto

Suportada versão 3 de Python
Escrito em Python 3.10
[![Updates](https://pyup.io/repos/github/juaoantonio/libpythonpro/shield.svg)](https://pyup.io/repos/github/juaoantonio/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/juaoantonio/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/juaoantonio/libpythonpro/)

Para instalar:
```console
$ python -m venv .venv
$ source .venv/bin/activate
```

Uso padrão:
```console
$ pip install -r requirements.txt
```

---

Se o uso for para desenvolvimento:
```console
$ pip install -r requirements-dev.txt
```

Para conferir a qualidade do código:
```console
$ flake8
```